@@ -86,10 +86,6 @@ class SeqFeature(object):
           analogous to the qualifiers from a GenBank feature table. The keys of
           the dictionary are qualifier names, the values are the qualifier
           values.
-        - sub_features - Obsolete list of additional SeqFeatures which was
-          used for holding compound locations (e.g. joins in GenBank/EMBL).
-          This is now superceded by a CompoundLocation as the location, and
-          should not be used (DEPRECATED).
     """
 
     def __init__(self, location=None, type='', location_operator='',
@@ -156,14 +152,8 @@ class SeqFeature(object):
         if qualifiers is None:
             qualifiers = {}
         self.qualifiers = qualifiers
-        if sub_features is None:
-            sub_features = []
-        else:
-            import warnings
-            from Bio import BiopythonDeprecationWarning
-            warnings.warn("Rather than sub_features, use a CompoundFeatureLocation",
-                          BiopythonDeprecationWarning)
-        self._sub_features = sub_features
+        if sub_features is not None:
+            raise TypeError("Rather than sub_features, use a CompoundFeatureLocation")
         if ref is not None:
             # TODO - Deprecation warning
             self.ref = ref
@@ -171,24 +161,6 @@ class SeqFeature(object):
             # TODO - Deprecation warning
             self.ref_db = ref_db
 
-    def _get_sub_features(self):
-        if self._sub_features:
-            import warnings
-            from Bio import BiopythonDeprecationWarning
-            warnings.warn("Rather using f.sub_features, f.location should be a CompoundFeatureLocation",
-                          BiopythonDeprecationWarning)
-        return self._sub_features
-
-    def _set_sub_features(self, value):
-        if value:
-            import warnings
-            from Bio import BiopythonDeprecationWarning
-            warnings.warn("Rather than f.sub_features, use a CompoundFeatureLocation for f.location",
-                          BiopythonDeprecationWarning)
-        self._sub_features = value
-    sub_features = property(fget=_get_sub_features, fset=_set_sub_features,
-                            doc="Obsolete representation of compound locations (DEPRECATED).")
-
     def _get_strand(self):
         return self.location.strand
 
@@ -289,25 +261,17 @@ class SeqFeature(object):
         for qual_key in sorted(self.qualifiers):
             out += "    Key: %s, Value: %s\n" % (qual_key,
                                                  self.qualifiers[qual_key])
-        # TODO - Remove this from __str__ since deprecated
-        if len(self._sub_features) != 0:
-            out += "Sub-Features\n"
-            for sub_feature in self._sub_features:
-                out += "%s\n" % sub_feature
         return out
 
     def _shift(self, offset):
         """Returns a copy of the feature with its location shifted (PRIVATE).
 
         The annotation qaulifiers are copied."""
-        answer = SeqFeature(location=self.location._shift(offset),
-                            type=self.type,
-                            location_operator=self.location_operator,
-                            id=self.id,
-                            qualifiers=dict(self.qualifiers.items()))
-        # This is to avoid the deprecation warning:
-        answer._sub_features = [f._shift(offset) for f in self._sub_features]
-        return answer
+        return SeqFeature(location=self.location._shift(offset),
+                          type=self.type,
+                          location_operator=self.location_operator,
+                          id=self.id,
+                          qualifiers=dict(self.qualifiers.items()))
 
     def _flip(self, length):
         """Returns a copy of the feature with its location flipped (PRIVATE).
@@ -319,15 +283,11 @@ class SeqFeature(object):
 
         The annotation qaulifiers are copied.
         """
-        answer = SeqFeature(location=self.location._flip(length),
-                            type=self.type,
-                            location_operator=self.location_operator,
-                            id=self.id,
-                            qualifiers=dict(self.qualifiers.items()))
-        # This is to avoid the deprecation warning:
-        answer._sub_features = [f._flip(length)
-                                for f in self._sub_features[::-1]]
-        return answer
+        return SeqFeature(location=self.location._flip(length),
+                          type=self.type,
+                          location_operator=self.location_operator,
+                          id=self.id,
+                          qualifiers=dict(self.qualifiers.items()))
 
     def extract(self, parent_sequence):
         """Extract feature sequence from the supplied parent sequence.
@@ -361,7 +321,7 @@ class SeqFeature(object):
            ...
         ValueError: The feature's .location is None. Check the sequence file for a valid location.
 
-        Note - currently only sub-features of type "join" are supported.
+        Note - currently only compound features of type "join" are supported.
         """
         if self.location is None:
             raise ValueError("The feature's .location is None. Check the "
@@ -569,8 +529,8 @@ class FeatureLocation(object):
     be described as running from a start position to and end position
     (optionally with a strand and reference information).  More complex
     locations made up from several non-continuous parts (e.g. a coding
-    sequence made up of several exons) are currently described using a
-    SeqFeature with sub-features.
+    sequence made up of several exons) are described using a SeqFeature
+    with a CompoundLocation.
 
     Note that the start and end location numbering follow Python's scheme,
     thus a GenBank entry of 123..150 (one based counting) becomes a location
@@ -918,12 +878,20 @@ class FeatureLocation(object):
 
     @property
     def start(self):
-        """Start location (integer like, possibly a fuzzy position, read only)."""
+        """Start location - left most (minimum) value, regardless of strand.
+
+        Read only, returns an integer like position object, possibly a fuzzy
+        position.
+        """
         return self._start
 
     @property
     def end(self):
-        """End location (integer like, possibly a fuzzy position, read only)."""
+        """End location - right most (maximum) value, regardless of strand.
+
+        Read only, returns an integer like position object, possibly a fuzzy
+        position.
+        """
         return self._end
 
     @property
@@ -1272,12 +1240,27 @@ class CompoundLocation(object):
 
     @property
     def start(self):
-        """Start location (integer like, possibly a fuzzy position, read only)."""
+        """Start location - left most (minimum) value, regardless of strand.
+
+        Read only, returns an integer like position object, possibly a fuzzy
+        position.
+
+        For the special case of a CompoundLocation wrapping the origin of a
+        circular genome, this will return zero.
+        """
         return min(loc.start for loc in self.parts)
 
     @property
     def end(self):
-        """End location (integer like, possibly a fuzzy position, read only)."""
+        """End location - right most (maximum) value, regardless of strand.
+
+        Read only, returns an integer like position object, possibly a fuzzy
+        position.
+
+        For the special case of a CompoundLocation wrapping the origin of
+        a circular genome this will match the genome length (minus one
+        given how Python counts from zero).
+        """
         return max(loc.end for loc in self.parts)
 
     @property
